<?php
namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\DTO\{ Request, Response};
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use Zeedhi\Framework\DataSource\DataSet;

use Ems\portalGestor\Service\ReportService;
use Ems\portalGestor\Util\ExpectedException;

class ReportController {

    /** @var ReportService */
    protected $reportService;

    public function __construct(
        ReportService $reportService
    ) {
        $this->reportService  = $reportService;
    }

    public function generateBirtReport(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            unset($row['requestType']);

            $reportLink = $this->reportService->generateBirtReport($row);

            $dataset = [
                'link' => $reportLink
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function downloadReport(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();
            $nrOrg = (int) $row['NRORG'];
            $link = (string) $row['link'];

            $file = $this->reportService->downloadReport($nrOrg, $link);

            $response->addDataSet(new DataSet('data', $file));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getGestorCanViewReport(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            $nrOrg = (int) $row['NRORG'];

            $canViewReport = $this->reportService->getGestorCanViewReport($nrOrg);

            $dataset = [
                'canView' => $canViewReport,
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

}
